@@ -35,15 +35,18 @@ class Fpm:
     """ Prepares arguments and executes fpm """
     fullVersion = version
     version = version.replace('local', '', 1)
-    # split version and revision
-    version_split = version.split('-')
-    # split in case of vX.Y.Z-R
-    # don't split if e.g. latest-o2-dataflow
-    if len(version_split) == 2:
-        version = version_split[0]
-        iterationArg = ['--iteration', version_split[1].replace('local', '', 1) + '.' + self.release_suffix]
-    else:
+
+    # Handle not standard versions, nightly, latest-o2-dataflow
+    if 'latest' in version:
         iterationArg = ['--iteration', self.release_suffix]
+    elif version.count('-') > 1:
+        version_split = version.split('-')
+        iterationArg = ['--iteration', version_split.pop() + '.' + self.release_suffix]
+        version = '_'.join(version_split)
+    else:
+        version_split = version.split('-', 1)
+        version = version_split[0]
+        iterationArg = ['--iteration', version_split[1].replace('-', '_') + '.' + self.release_suffix]
 
     rpmType = 'dir'
     # prep dir arguments
@@ -92,7 +95,11 @@ class Fpm:
       '--no-rpm-auto-add-directories',
       '--template-scripts',
       '--after-install', os.path.join(config.work_dir, 'after_install_template.sh'),
-      '--after-remove', os.path.join(config.work_dir, 'after_remove_template.sh')]
+      '--after-remove', os.path.join(config.work_dir, 'after_remove_template.sh'),
+      '--vendor', 'ALICE FLP',
+      '--url', 'https://alice-flp.docs.cern.ch',
+      '--maintainer', 'Adam Wegrzynek <adam.wegrzynek@cern.ch>',
+      '--license', 'GPL-3.0']
 
     if paths:
         fpmCommand.extend(['--exclude=*/modulefiles', '--exclude=*/profile.d', '--exclude=*/info/dir', '--exclude=*/version'])
@@ -162,10 +169,8 @@ class Fpm:
     for depName, depVersion in deps.items():
       if depName not in self.skipDeps:
         if (depVersion != "from_system"):
-            countDashes = depVersion.count('-')
-            if countDashes > 1:
-                depVersion = depVersion.replace('-', '_', countDashes - 1)
-            depsArg.extend(['--depends', self.packagePrefix + depName + ' >= ' + depVersion.replace('local', '', 1)])
+            depVersion = self.stripDashes(depVersion)
+            depsArg.extend(['--depends', self.packagePrefix + depName + ' >= ' + depVersion])
         else:  # coming from system, get name from dict
           if depName not in self.runtimeDepsDict:
             logging.critical('Could not find system dependency: %s \nDoes it suppose to come from aliBuild?' % (depName))
@@ -174,6 +179,16 @@ class Fpm:
             depsArg.extend(['--depends', dep])
     return depsArg
 
+  def stripDashes(self, version):
+      """ Replaces last dash with underscore, execpt last one """
+      version = version.replace('local', '', 1)
+      if version.count('-') > 1:
+          version_split = version.split('-')
+          release = version_split.pop()
+          return '_'.join(version_split) + '-' + release
+      else:
+          return version
+
   def validateRpms(self):
       """ Validates the generated RPMs by running a dry yum install """
 
